xsdata.codegen.handlers.attribute\_merge module
===============================================

.. automodule:: xsdata.codegen.handlers.attribute_merge
   :members:
   :undoc-members:
   :show-inheritance:
